@@ -1,8 +1,8 @@
 # invyrfraction.R
 # convert fraction of the year into a date (day and month)
 # month on a scale of [1,13)
-# type =  monthly/daily
-# Oct 2011
+# type =  monthly/weekly/daily
+# Jan 2014
 
 invyrfraction<-function(frac,type='daily',text=TRUE){
   n<-length(frac)
@@ -13,7 +13,7 @@ invyrfraction<-function(frac,type='daily',text=TRUE){
      day=day-(365*as.numeric(day>365)); # avoid values > 365
      day=pmax(day,1); # avoid values < 1
      date<-strptime(day,'%j');
-     day<-as.numeric(format(date,'%d')); # Day of the month as decimal number (0131)
+     day<-as.numeric(format(date,'%d')); # Day of the month as decimal number (01?31)
      month<-format(date,'%B'); # Month name
      if (text==TRUE){daym<-paste('Month =',month,', day =',day)}
      if (text==FALSE){
@@ -22,6 +22,11 @@ invyrfraction<-function(frac,type='daily',text=TRUE){
         daym<-monthnum+((day-1)/mnthlength[monthnum])
      } # 
   }
+  if (type=='weekly'){
+    week<-(frac*52)+1;
+    if (text==TRUE){daym<-paste('Week =',round(week,1))}
+    if (text==FALSE){daym<-week}
+  }
   if (type=='monthly'){
      month<-(frac*12)+1;
      if (text==TRUE){daym<-paste('Month =',round(month,1))}
